/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model.framestore;

import java.util.Collection;
import java.util.List;
import java.util.Set;

import edu.stanford.smi.protege.model.Facet;
import edu.stanford.smi.protege.model.Frame;
import edu.stanford.smi.protege.model.Slot;

/**
 * This interface maintains a mapping between frames in two 
 * Narrow Frame Stores (a local vs a global Narrow Frame Store).
 */
public interface FrameMapping {
  Frame mapGlobalFrame(Frame frame, boolean create);
  Frame mapLocalFrame(Frame frame);

  Slot mapGlobalSlot(Slot slot, boolean create);
  Slot mapLocalSlot(Slot slot);

  Facet mapGlobalFacet(Facet slot, boolean create);
  Facet mapLocalFacet(Facet slot);

  Object mapLocalObject(Object o);
  Object mapGlobalObject(Object o, boolean create);
  
  List mapGlobalList(List c, boolean create);
  List mapLocalList(List c);

  Collection mapGlobalCollection(Collection c, boolean create);
  Collection mapLocalCollection(Collection c);

  Set<Frame> mapLocalFrameSet(Set<Frame> localFrames);
  
}