/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model.framestore.undo;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.model.framestore.*;

class SetFrameNameCommand extends AbstractCommand {
    private String name;
    private Frame frame;
    private String oldName;

    SetFrameNameCommand(FrameStore delegate, String name, Frame frame) {
        super(delegate);
        this.name = name;
        this.frame = frame;
        oldName = getDelegate().getFrameName(frame);
        setDescription("Change frame name from " + oldName + " to " + name);
    }

    public Object doIt() {
        getDelegate().setFrameName(frame, name);
        return null;
    }

    public void undoIt() {
        getDelegate().setFrameName(frame, oldName);
    }

    public void redoIt() {
        getDelegate().setFrameName(frame, name);
    }
}