/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server;

import edu.stanford.smi.protege.model.KnowledgeBase;
import edu.stanford.smi.protege.model.framestore.FrameStore;
import edu.stanford.smi.protege.model.framestore.NarrowFrameStore;


/**
 * This interface provides a KnowledgeBaseFactory a chance to perform
 * initialization on the client side of a server client relationship.
 * 
 * Unlike other Project implementations, the Remote client project does not
 * call either factory.createNarrowFrameStore,
 * factory.loadKnowledgeBase, or factory.includeKnowledgeBase.  This
 * means that the factory loses several opportunities to initialize
 * the knowledgebase.  In particular, the OWL factories need these
 * opportunities or several of their datastructures will not be set up
 * correctly.  This interface (a bit of a kludge) is here to
 * provide the factory component with an opportunity to do this initialization.
 *
 */
public interface ClientInitializerKnowledgeBaseFactory {

  void initializeClientKnowledgeBase(FrameStore fs,
                                     NarrowFrameStore systemNfs,
                                     NarrowFrameStore nfs, 
                                     KnowledgeBase kb);

}