/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.metaproject.impl;

import java.util.HashSet;
import java.util.Set;

import sun.security.jca.GetInstance;

import edu.stanford.smi.protege.exception.OntologyException;
import edu.stanford.smi.protege.model.Instance;
import edu.stanford.smi.protege.server.metaproject.GroupInstance;
import edu.stanford.smi.protege.server.metaproject.Operation;
import edu.stanford.smi.protege.server.metaproject.UserInstance;
import edu.stanford.smi.protege.server.metaproject.MetaProject.ClsEnum;
import edu.stanford.smi.protege.server.metaproject.MetaProject.SlotEnum;
import edu.stanford.smi.protege.util.Log;

public class GroupInstanceImpl extends WrappedProtegeInstanceImpl implements GroupInstance {
  public static final String WORLD = "World";
  
  protected GroupInstanceImpl(MetaProjectImpl mp, Instance group) 
  throws OntologyException {
    super(mp, group, ClsEnum.Group);
 
  }

  public String getName() throws OntologyException {
    Object value = getProtegeInstance().getOwnSlotValue(getMetaProject().getSlot(SlotEnum.name));
    if (!(value instanceof String)) {
      throw new OntologyException("The " + SlotEnum.name + " slot should take on string values");
    }
    return (String) value;
  }
  
  @SuppressWarnings("unchecked")
  public Set<UserInstance> getMembers() {
    return (Set<UserInstance>) getSlotValues(SlotEnum.member, ClsEnum.User);
  }
  
  public String toString() {
    return getName();
  }
}
