/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.storage.database;

import java.sql.SQLException;
import java.util.EnumSet;


public class SelectStatement<X extends Enum<X>> {
  private final EnumSet<X> cols;
  private String stmt;
  
  public SelectStatement(EnumSet<X> cols) {
    this.cols = cols;
  }
  
  public String toString() {
    if (stmt == null) {
      stmt = "Select ";
      boolean firstTime = true;
      for (X col : cols) {
        if (firstTime) {
          firstTime = false;
        } else {
          stmt += ", ";
        }
        stmt += col;
      }
      stmt += " ";
    }
    return stmt;
  }
  
  public int rsIndex(X col) throws SQLException {
    int i = 1;
    for (X foundCol : cols) {
      if (foundCol == col) {
        return i;
      }
      i++;
    }
    throw new SQLException("Missing index - probably implementation Error");
  }

}
