/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

import java.io.*;
import java.net.*;
import java.util.*;

/**
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class DirectoryClassLoader extends URLClassLoader {
    private File directory;

    private static FilenameFilter jarFilter = new FilenameFilter() {
        public boolean accept(File dir, String name) {
            return name.endsWith(".jar");
        }
    };

    public DirectoryClassLoader(File directory, ClassLoader parent) {
        super(getURLs(directory), parent);
        this.directory = directory;
    }

    private static URL[] getURLs(File directory) {
        Collection urls = new ArrayList();
        if (directory != null) {
            urls.add(FileUtilities.toURL(directory));
            File[] jarFiles = directory.listFiles(jarFilter);
            if (jarFiles != null) {
                for (int i = 0; i < jarFiles.length; ++i) {
                    File jarFile = jarFiles[i];
                    urls.add(FileUtilities.toURL(jarFile));
                }
            }
        }
        return (URL[]) urls.toArray(new URL[urls.size()]);
    }

    public File getDirectory() {
        return directory;
    }

    public URL findResource(String resource) {
        URL url = null;
        File file = new File(directory, resource);
        if (file.exists()) {
            url = FileUtilities.toURL(file);
        }
        if (url == null) {
            url = super.findResource(resource);
        }
        return url;
    }

    public String toString() {
        return StringUtilities.getClassName(this) + "(" + directory + ", " + getParent() + ")";
    }
}
