/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util.transaction;


/**
 * This interface represents a simple cache mechanism for storing cached  
 * values either globally or on a per session basis.  This cache mechanism is 
 * caching the values (of type R) of a variable (of type V).
 * 
 * The global cache is to be interpreted as the latest data from the database.
 * The session cache is a cache of data as found in the a transactionn for a session.
 * 
 * @author tredmond
 *
 * @param <V> the variable type
 * @param <R> the result set type
 */
public interface Cache<V, R> {
 
  /**
   * determines if the variable var is cached in the global cache.
   * isCached(var) should always be checked before calling read(var).
   * 
   * @param var a variable
   * @return whether the variable is cached.
   */
  boolean isCached(V var);
  
  /**
   * If  the variable var is cached then this returns the cached
   * value.  It can be null.
   * 
   * @param var a variable
   * @return the value in the cache for the variable var.
   */
  R readCache(V var);
  
  /**
   * Writes the value result to the global cache for the variable 
   * var.
   * 
   * @param var a variable
   * @param result the cached value for the variable.
   */
  void writeCache(V var, R result);
  
  /**
   * Invalidates the global cache  for the variable  var.
   * 
   * @param var a variable
   */
  void removeCacheEntry(V var);
}
