/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util.transaction;

import java.util.logging.Level;

import edu.stanford.smi.protege.exception.TransactionException;
import edu.stanford.smi.protege.server.RemoteSession;
import edu.stanford.smi.protege.util.Log;

public class TransactionCacheImpl<V, R> extends TransactionCache<V, R> {
  private TransactionMonitor transactionMonitor;
  private TransactionIsolationLevel level;
  private boolean disabled = false;     
  
  public TransactionCacheImpl(TransactionMonitor transactionMonitor) {
    super(new CacheImpl<V,R>());
    this.transactionMonitor = transactionMonitor;
  }
  
  public boolean inTransaction() {
    return transactionMonitor != null && transactionMonitor.inTransaction();
  }
  
  public TransactionIsolationLevel getTransactionIsolationLevel() {
    if (level == null) {
      if (transactionMonitor == null) {
        level = TransactionIsolationLevel.NONE;
      }
      try {
        level = transactionMonitor.getTransationIsolationLevel();
      } catch (TransactionException e) {
        disabled = true;
        Log.getLogger().log(Level.WARNING, "Could not determine trahsaction isolation level", e);
        Log.getLogger().warning("Caching disabled");
      }
    }
    return level;
  }
  
  public void resetTransactionIsolationLevel() {
    level = null;
  }
  
  public boolean isDisabled() {
    return disabled;
  }

  @Override
  public LosslessCache createSessionCache(RemoteSession session) {
    return new LosslessCacheImpl();
  }
  
}

