/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.widget;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.resource.*;

/**
 * The slot widget for displaying and editing frame documentation.  This looks trivial but there is something funny 
 * going on behind the scenes.  Documentation is a cardinality multiple slot because the OKBC spec declares it to be so.
 * This would be clumsy (and pointless) to use though, especially since there is no "key" for each of the "values" of 
 * documentation.  Thus we just use a cardinality single widget to edit this cardinality multiple slot.  The down side
 * of this is that if the slot actually does have multiple values (set with the api, for example), not only will they
 * not get displayed, they will get lost when the user edits the displayed (first) value.
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class DocumentationWidget extends TextAreaWidget {

    public static boolean isSuitable(Cls cls, Slot slot, Facet facet) {
        return slot.getName().equals(Model.Slot.DOCUMENTATION);
    }
    
    public String getLabel() {
        return localizeStandardLabel(super.getLabel(), "Documentation", ResourceKey.DOCUMENTATION_SLOT_WIDGET_LABEL);
    }
}
