/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.widget;

import java.util.*;

import javax.swing.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.resource.*;
import edu.stanford.smi.protege.ui.*;
import edu.stanford.smi.protege.util.*;

/**
 * Widget for acquiring a list of symbol values.  This widget is of limited use but is included for completeness.
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class SymbolListWidget extends AbstractListWidget {

    private String edit(String label, Object initialValue) {
        Collection allowedValues = getCls().getTemplateSlotAllowedValues(getSlot());
        return (String) DisplayUtilities.pickSymbol(this, label, initialValue, allowedValues);
    }

    private Action getCreateAction() {
        return new CreateAction(ResourceKey.VALUE_ADD) {
            public void onCreate() {
                handleCreateAction();
            }
        };
    }

    private Action getEditAction() {
        return new ViewAction(ResourceKey.VALUE_VIEW, this) {
            public void onView(Object o) {
                handleViewAction((String) o);
            }
        };
    }

    private Action getRemoveAction() {
        return new RemoveAction(ResourceKey.VALUE_REMOVE, this) {
            public void onRemove(Collection values) {
                handleRemoveAction(values);
            }
        };
    }

    protected void handleCreateAction() {
        String s = edit("Create Symbol", null);
        if (s != null) {
            addItem(s);
        }
    }

    protected void handleRemoveAction(Collection values) {
        removeItems(values);
    }

    protected void handleViewAction(String symbol) {
        String s = edit("Edit Symbol", symbol);
        if (s != null) {
            replaceItem(symbol, s);
        }
    }

    public void initialize() {
        Action editAction = getEditAction();
        super.initialize(editAction);
        addButton(editAction);
        addButton(getCreateAction());
        addButton(getRemoveAction());
    }

    public static boolean isSuitable(Cls cls, Slot slot, Facet facet) {
        boolean isSuitable;
        if (cls == null || slot == null) {
            isSuitable = false;
        } else {
            boolean isString = equals(cls.getTemplateSlotValueType(slot), ValueType.SYMBOL);
            boolean isMultiple = cls.getTemplateSlotAllowsMultipleValues(slot);
            isSuitable = isString && isMultiple;
        }
        return isSuitable;
    }
}
